Module item

Module item 

Sequences and Items.

A Sequence is the fundamental data type in XPath. It is a series of zero or more Items.

An Item is a Node, Function or atomic Value.

Nodes are defined as a trait.

Enums

Item
An Item in a Sequence. Can be a node, function or Value.
NodeType
All Nodes have a type. The type of the Node determines what components are meaningful, such as name and content.

Traits

Node
Nodes make up a document tree. Nodes must be fully navigable. The tree must be mutable but also stable (i.e. removing a node from the tree does not invalidate the remaining nodes).
SequenceTrait

Type Aliases

Sequence
In XPath, the Sequence is the fundamental data structure. It is an ordered collection of Items. The Rust implementation is a Vector of reference counted Items.