Module many

Module many 

Functions

many0
many0nsreset
This is a special combinator, it will reset namespaces on the parser state between iterations It is only intended for use when parsing the children of an element node.
many1