many0nsreset

Function many0nsreset 

pub fn many0nsreset<'a, P, R, N: Node, L>(
    parser: P,
) -> impl Fn(ParseInput<'a, N>, &mut StaticState<L>) -> Result<(ParseInput<'a, N>, Vec<R>), ParseError>
where P: Fn(ParseInput<'a, N>, &mut StaticState<L>) -> Result<(ParseInput<'a, N>, R), ParseError>, L: FnMut(&NamespacePrefix) -> Result<NamespaceUri, ParseError>,
This is a special combinator, it will reset namespaces on the parser state between iterations It is only intended for use when parsing the children of an element node.