pub enum Feature<N: Node> {
Permitted(Option<Transform<N>>),
NotPermitted,
}Expand description
A security feature. These limit or constrain acccess to a resource. Access to a resource may, or may not, be permitted. If access is permitted, then it may also be constrained so some maximum value. This value is computed dynamically using a Transform. If no Transform is given then the access to the resource is unlimited.
Variants
Implementations
Sourceimpl<N: Node> Feature<N>
impl<N: Node> Feature<N>
Sourcepub fn get(&self, a: ActualParameters<N>) -> Result<SecurityResult, Error>
pub fn get(&self, a: ActualParameters<N>) -> Result<SecurityResult, Error>
Determine whether this security feature is permitted, and if so then to what limit, i.e. a maximum value.