pub enum SecurityResult {
Permitted(Option<String>),
NotPermitted,
}Expand description
The result of determining the limitation or constraint for a security feature. Permitted means that the application is allowed to access the resource. The contained value is a limit on the usage of the resource. If it is None then there is no limit on resource usage, or the module may impose a default limit. NotPermitted means that the application is not allowed to access the resource at all, or the module may impose a default limit.
Variants