SecurityPolicies

Struct SecurityPolicies 

pub struct SecurityPolicies<N: Node> { /* private fields */ }
All of the security policies available for use, indexed by name. One of these policies may be in force (or “active”).

Implementations

Source

impl<N: Node> SecurityPolicies<N>

pub fn new() -> Self

Create a new set of security policies.

pub fn push(&mut self, policy: Policy<N>)

Add a new security policy

pub fn find(&self, name: QName) -> Option<&Policy<N>>

Look up a security policy by name

pub fn activate(&mut self, name: &QName) -> Option<&Policy<N>>

Make the named security policy the “in force” (or “active”) policy.

pub fn get( &self, f: &QName, a: ActualParameters<N>, ) -> Result<SecurityResult, Error>

Determine whether a feature, in the in-force policy, is permitted. All parameters must be named, i.e. positional parameters are ignored.