Module trees

Module trees 

Various implementations of tree data structures.

Modules

smite
Interior Mutability Tuple-Struct with Enum. This tree implementation is an evolution of intmuttree that represents each type of node as variants in an enum, wrapped in a tuple struct.