Module xmldecl
xrust
0.1.0
Module xmldecl
Module Items
Structs
Enums
In crate xrust
xrust
Module
xmldecl
Defines common features of XML documents.
Structs

DTD
DTD declarations. Data is not stored in any fashion conformant with any standard and will be adusted to meet the needs of any validators implemented.
XMLDecl
XMLDecl
Builder
Enums

DTDDecl