DTD

Struct DTD 

pub struct DTD { /* private fields */ }
DTD declarations. Data is not stored in any fashion conformant with any standard and will be adusted to meet the needs of any validators implemented.

NB. Names of elements and attributes cannot be stored as QName, since in the DTD it is not possible to resolve the Namespace URI. Instead, they are stored here as a (prefix, local-part) pair.

Implementations

Source

impl DTD

pub fn new() -> DTD