XSLT

Trait XSLT 

pub trait XSLT: Node {
    // Required method
    fn transform<N: Node, F, G>(
        &self,
        src: Rc<Item<N>>,
        b: Option<Url>,
        f: F,
        g: G,
    ) -> Result<Sequence<N>, Error>
       where F: Fn(&str) -> Result<N, Error>,
             G: Fn(&Url) -> Result<String, Error>;
}
The XSLT trait allows an object to use an XSL Stylesheet to transform a document into a Sequence.

Required Methods

fn transform<N: Node, F, G>( &self, src: Rc<Item<N>>, b: Option<Url>, f: F, g: G, ) -> Result<Sequence<N>, Error>
where F: Fn(&str) -> Result<N, Error>, G: Fn(&Url) -> Result<String, Error>,

Interpret the object as an XSL Stylesheet and transform a source document. The Node that is given as the source document becomes the initial context for the transformation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors