Enums
- Item
- An Item in a Sequence. Can be a node, function or Value.
- Node
Type - All Nodes have a type. The type of the Node determines what components are meaningful, such as name and content.
Traits
- Node
- Nodes make up a document tree. Nodes must be fully navigable. The tree must be mutable but also stable (i.e. removing a node from the tree does not invalidate the remaining nodes).
- Sequence
Trait