A parser combinator, inspired by nom.
This parser combinator passes a context into the function, which includes the string being parsed. This supports resolving context-based constructs such as general entities and XML Namespaces.
Modules
- avt
- Parse an Attribute Value Template.
- combinators
- datetime
- parsepicture
- xml
- xpath
- Parse XPath expressions
Structs
- Parser
State - Parser state that can be cloned
- Parser
State Builder - Static
State - Parser state configuration that cannot be cloned. Also state that needs to be persistent during parsing.
- Static
State Builder