pub enum Pattern<N: Node> {
Predicate(Transform<N>),
Selection(Path),
Error(Error),
}Expand description
An XPath pattern. A pattern most frequently appears as the value of a match attribute. A pattern is either a predicate pattern or a selection pattern.
A predicate pattern matches the current item if all of the predicates evaluate to true.
A selection pattern is subset of XPath path expressions.
Variants
Implementations
Sourceimpl<N: Node> Pattern<N>
impl<N: Node> Pattern<N>
pub fn get_err(&self) -> Option<Error>
Sourcepub fn matches<F: FnMut(&str) -> Result<(), Error>, G: FnMut(&str) -> Result<N, Error>, H: FnMut(&Url) -> Result<String, Error>>(
&self,
ctxt: &Context<N>,
stctxt: &mut StaticContext<N, F, G, H>,
i: &Item<N>,
) -> bool
pub fn matches<F: FnMut(&str) -> Result<(), Error>, G: FnMut(&str) -> Result<N, Error>, H: FnMut(&Url) -> Result<String, Error>>( &self, ctxt: &Context<N>, stctxt: &mut StaticContext<N, F, G, H>, i: &Item<N>, ) -> bool
Returns whether the given item matches the pattern. TODO: return dynamic errors
Sourcepub fn terminal_node_test(&self) -> (Axis, Axis, NodeTest)
pub fn terminal_node_test(&self) -> (Axis, Axis, NodeTest)
Find the NodeTest for the terminal step