pub struct SecurityPolicies<N: Node> { /* private fields */ }Expand description
All of the security policies available for use, indexed by name. One of these policies may be in force (or “active”).
Implementations
Sourceimpl<N: Node> SecurityPolicies<N>
impl<N: Node> SecurityPolicies<N>
Sourcepub fn activate(&mut self, name: &QName) -> Option<&Policy<N>>
pub fn activate(&mut self, name: &QName) -> Option<&Policy<N>>
Make the named security policy the “in force” (or “active”) policy.
Sourcepub fn get(
&self,
f: &QName,
a: ActualParameters<N>,
) -> Result<SecurityResult, Error>
pub fn get( &self, f: &QName, a: ActualParameters<N>, ) -> Result<SecurityResult, Error>
Determine whether a feature, in the in-force policy, is permitted. All parameters must be named, i.e. positional parameters are ignored.