Callables
Sequence constructors that are invoked by stylesheet code, such as named templates and functions. The difference between them is that named templates have named parameters, whereas functions have positional parameters.
Structs
Enums
Functions
- invoke
- Invoke a callable component