An atomic value.
An atomic value that is an item in a sequence.
Structs
- ENTITY
- An XML Entity (XML production 56) must match the Name production (5): Name ::= NameStartChar NameChar*
- ID
- An XML ID (XML production 56) must match the Name production (5): Name ::= NameStartChar NameChar* An ID must be unique within a document. It is the responsibility of the document to check for compliance.
- IDREF
- An XML IDREF (XML production 56) must match the Name production (5): Name ::= NameStartChar NameChar*
- NCName
- An NCName for XML Namespaces.
- NMTOKEN
- An XML NMTOKEN (XML production 56) must match the Nmtoken production (7): Nmtoken ::= NameChar+
- Name
- An XML Name (XML production 5): Name ::= NameStartChar NameChar*
- Negative
Integer - NonNegative
Integer - NonPositive
Integer - Normalized
String - Positive
Integer - Value
- A concrete type that implements atomic values. These are the 19 predefined types in XSD Schema Part 2, plus five additional types. Also included is a hint for serialisation for if the value should be escaped.
- Value
Builder