pub trait XSLT: Node {
// Required method
fn transform<N: Node, F, G>(
&self,
src: Rc<Item<N>>,
b: Option<Url>,
f: F,
g: G,
) -> Result<Sequence<N>, Error>
where F: Fn(&str) -> Result<N, Error>,
G: Fn(&Url) -> Result<String, Error>;
}Expand description
The XSLT trait allows an object to use an XSL Stylesheet to transform a document into a Sequence.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".